ifgen.enum.python package — docs

Skip to main content
`Ctrl`+`K`

# ifgen.enum.python package

## Module contents

A module implementing Python enum-generation interfaces.

ifgen.enum.python.python_enum_header(task: GenerateTask, writer: IndentedFileWriter) → None

  Create a Python module for an enumeration.

ifgen.enum.python.strip_t_suffix(data: str) → str

  Strip a possible ‘_t’ suffix from a string.

ifgen.enum.python.to_enum_name(data: str) → str

  Ensure a candidate name string is suitable as an enumeration name.

ifgen.enum.python.uses_auto(task: GenerateTask) → bool

  Determine if a generation task will require ‘auto’ from the enum module.